pub struct ScopeKey(/* private fields */);Trait Implementations
Sourceimpl Key for ScopeKey
impl Key for ScopeKey
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for ScopeKey
impl Ord for ScopeKey
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ScopeKey
impl PartialOrd for ScopeKey
impl Copy for ScopeKey
impl Eq for ScopeKey
impl StructuralPartialEq for ScopeKey